import unittest
import sys
sys.path.append("../MqttImageUploader")
import json

import MqttImageUploader as miu

url = "159.100.249.153"
# url = "192.168.1.23"
# port = 1883
port = 8883
tls = True
def publish_callback(client, userdata, result):
    print("published data motherfuckers")
    print(result)
    print("there was the result")
class MqttImageUploaderTest(unittest.TestCase):

    def testPublish(self):

       uploader = miu.MqttImageUploader(url, port, "zero/test/images",tls, "/home/ep/certs/zero-mqtt/ca.crt", "/home/ep/certs/zero-mqtt/client.crt","/home/ep/certs/zero-mqtt/client.key" )

       j = dict()
       j['timestamp'] = 123123123
       j['farmId'] = "valliFarm"
       j['batchId'] = "valliBatchSmall"
       j['lineId'] = 2
       j['fake'] = 420
       j['type'] = "image"
       uploader.UploadData(
            "./farmerbig.jpg", json.dumps(j), publish_callback)



    def testWithDictionryJson(self):
       uploader = miu.MqttImageUploader(url,port, "zero/test/images",tls, "/home/ep/certs/zero-mqtt/ca.crt", "/home/ep/certs/zero-mqtt/client.crt","/home/ep/certs/zero-mqtt/client.key" )
       j = dict()
       j['timestamp'] = 123123123
       j['farmId'] = "valliFarm"
       j['batchId'] = "valliBatchBig"
       j['lineId'] = 2
       j['fake'] = 420
       j['type'] = "image"
       uploader.UploadData('./farmerbig.jpg', json.dumps(j), publish_callback)

 

if __name__ == '__main__':
    unittest.main()



import io
import time
import paho.mqtt.client as mqtt
import ssl
import base64
import json
from io import BytesIO

from PIL import Image, ImageColor


def on_connect(client, userdata, flags, rc):
    print("Connected with result code " + str(rc))

# def on_message(client, userdata, msg):
# 	print(msg.topic+" "+str(msg.payload))


def on_publish(client, userdata, result):
    print("data published \n")
    print(result)


class MqttImageUploader:
    def __init__(self, host, port, topic, tls, ca_certificate, client_certificate, client_key):
        self.host = host
        self.port = port
        self.topic = topic
        self.ca_certificate = ca_certificate
        self.client_key = client_key
        self.client_certificate = client_certificate
        self.tls = tls

    def UploadData(self, image_name, json_string, callback):
        client = mqtt.Client()
        if self.tls:
             
            client.tls_set(self.ca_certificate ,self.client_certificate, self.client_key, cert_reqs=ssl.CERT_NONE,tls_version=ssl.PROTOCOL_TLSv1_2)
            client.tls_insecure_set(True)
            client.on_connect = on_connect
            client.on_publish = callback
        print "connecting to %s on port %s\npublishing on topic %s" % (
            self.host, self.port, self.topic)
        client.connect(self.host, self.port, 60)
        client.loop_start()
        # img = Image.open(image_name)
        imgFile = open(image_name,"r")
        img = imgFile.read()
        # asString = base64.b64encode(img.tobytes())
        asString = base64.b64encode(img)
        j = json.loads(json_string)
        j['image'] = asString
        j['timestamp'] = time.time()
        client.publish(self.topic, json.dumps(j), qos=0)
        client.loop_stop()
